@@ -1,6 +1,7 @@
-from signal_pkg.signaux.signal_fourier import SignalFourier
-from signal_pkg.signaux.signal_gbf import SignalGBF
-from signal_pkg.signaux.signal_sysam import SignalSysam
+from signal_pkg.signaux.signal_fourier import Fourier
+from signal_pkg.signaux.signal_gbf import GBF
+from signal_pkg.signaux.signal_sysam import Sysam
+from signal_pkg.signaux.signal_custom import Perso
 
 from signal_pkg.affichages.signal_plot import tracer_signaux
 from signal_pkg.affichages.signal_fft_plot import tracer_spectres
