@@ -13,21 +13,20 @@ import numpy as np
 sys.path.append(os.path.join(os.path.dirname(os.path.realpath(__file__)), os.pardir))
 
 import base.constantes_base as cst
+import base.utiles_base as utb
 from base.temps_base import BaseTemps
 from signaux.signal_complet import SignalComplet
 
 
+
 import matplotlib.pyplot as plt
  
-__all__ = ["SignalFourier"]
+__all__ = ["Fourier"]
 
 
-def periodiser(N, vecteur_signal_periode):
-    Nperiode = len(vecteur_signal_periode)
-    Pperiodes = int(np.ceil(N/Nperiode))
-    return np.concatenate([vecteur_signal_periode]*Pperiodes)[0:N]
 
-class SignalFourier(SignalComplet):
+
+class Fourier(SignalComplet):
     def __init__(self, F, liste_an, liste_bn, liste_tmin_tmax = cst.liste_tmin_tmax, Te = cst.Te, nom = ""):
         base_de_temps_periode = BaseTemps([0, 1/F], Te)
         base_de_temps = BaseTemps(liste_tmin_tmax, Te)
@@ -51,13 +50,13 @@ class SignalFourier(SignalComplet):
             vecteur_signal_periode = vecteur_signal_periode + liste_bn[i]*np.sin(2*np.pi*fi*vecteur_t_periode)
 
 
-        SignalComplet.__init__(self, base_de_temps, periodiser(Nsignal, vecteur_signal_periode), nom)
+        SignalComplet.__init__(self, base_de_temps, utb.periodiser(Nsignal, vecteur_signal_periode), nom)
         self.mesures.T_th = 1/F
 
 
 if __name__ == "__main__":
 
-    s1 = SignalFourier(1e3, [1,1], [], nom="$s_1$")
+    s1 = Fourier(1e3, [1,1], [], nom="$s_1$")
 
     s1.tracer_signal()
 
