@@ -22,7 +22,7 @@ import base.utiles_base as utb
 
 
 class Sysam3Test(Sysam2Mode):
-    def __init__(self, liste_signaux = None):
+    def __init__(self, liste_signaux):
         Sysam2Mode.__init__(self, liste_signaux)
         if self.tester_liste_signaux():
             self.test_signaux = True
